km3pipe\.dataclasses\.RawHitSeries
==================================

.. currentmodule:: km3pipe.dataclasses

.. autoclass:: RawHitSeries

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~RawHitSeries.__init__
      ~RawHitSeries.append_fields
      ~RawHitSeries.conv_from
      ~RawHitSeries.conv_to
      ~RawHitSeries.deserialise
      ~RawHitSeries.from_aanet
      ~RawHitSeries.from_arrays
      ~RawHitSeries.next
      ~RawHitSeries.serialise
      ~RawHitSeries.sorted
   
   

   
   
   